import typer
from db.database import Session
from models import Contact

def add_contact(
    name_first: str = typer.Option(..., "--name-first", help="First name of the contact"),
    name_last: str = typer.Option(..., "--name-last", help="Last name of the contact"),
    email: str = typer.Option(..., "--email", help="Email address of the contact")
):
    """
    Add a new contact to the database
    """
    # Create a new contact
    contact = Contact(
        name_first=name_first,
        name_last=name_last,
        email=email,
        is_dirty=True,  # Mark as dirty for sync
        sync_status="PENDING_ADD"
    )
    
    # Get a database session
    session = Session()
    try:
        # Add the contact to the database
        session.add(contact)
        session.commit()
        
        # Print success message with the contact ID
        typer.echo(f"Contact added successfully with ID: {contact.local_id}")
        return contact
    except Exception as e:
        session.rollback()
        typer.echo(f"Error adding contact: {str(e)}", err=True)
        raise
    finally:
        session.close()