import uuid
import typer
from db.database import Session
from models import Contact, Interaction

def add_interaction(
    contact_id: str,
    type: str = typer.Option(..., "--type", help="Type of interaction (e.g., note, call, meeting)"),
    text: str = typer.Option(..., "--notes", help="Notes about the interaction")
):
    """
    Add a new interaction for a contact
    """
    # Get a database session
    session = Session()
    try:
        # Convert string to UUID
        contact_uuid = uuid.UUID(contact_id)
        
        # Check if contact exists
        contact = session.query(Contact).filter(Contact.local_id == contact_uuid).first()
        if not contact:
            typer.echo(f"Contact with ID {contact_id} not found.")
            return
        
        # Create a new interaction
        interaction = Interaction(
            contact_id=contact_uuid,
            type=type,
            text=text,
            is_dirty=True,
            sync_status="PENDING_ADD"
        )
        
        # Add the interaction to the database
        session.add(interaction)
        session.commit()
        
        # Print success message
        typer.echo(f"Interaction added successfully for contact: {contact.name_first} {contact.name_last}")
        typer.echo(f"Interaction ID: {interaction.local_id}")
        return interaction
    except ValueError:
        typer.echo(f"Invalid UUID format: {contact_id}", err=True)
    except Exception as e:
        session.rollback()
        typer.echo(f"Error adding interaction: {str(e)}", err=True)
        raise
    finally:
        session.close()