#!/usr/bin/env python3
"""
Simple sync module for debugging purposes.
"""
import sys
import platform
import typer

def check_platform():
    """Simple function to check if we're on macOS."""
    try:
        # Print out platform and Python version info
        print(f"Python version: {sys.version}")
        print(f"Platform: {platform.platform()}")
        
        # Check if we're on macOS
        if platform.system() == 'Darwin':
            print("Running on macOS")
            
            # Try to import PyObjC
            try:
                import objc
                print(f"PyObjC version: {objc.__version__}")
                
                # Try to import Contacts framework
                try:
                    import Contacts
                    print("Successfully imported Contacts framework")
                    return True
                except ImportError as e:
                    print(f"Failed to import Contacts framework: {str(e)}")
                    return False
            except ImportError as e:
                print(f"Failed to import PyObjC: {str(e)}")
                return False
        else:
            print(f"Not running on macOS. Platform: {platform.system()}")
            return False
    except Exception as e:
        print(f"Error in check_platform: {type(e).__name__}: {str(e)}")
        import traceback
        print(traceback.format_exc())
        return False