#!/usr/bin/env python3
import datetime
from pathlib import Path

def get_last_sync_date():
    """Get the last time we synced with macOS Contacts."""
    config_dir = Path.home() / ".contactcmd"
    config_dir.mkdir(exist_ok=True)
    
    sync_file = config_dir / "mac_sync_timestamp"
    if sync_file.exists():
        try:
            with open(sync_file, "r") as f:
                timestamp = float(f.read().strip())
                return datetime.datetime.fromtimestamp(timestamp)
        except (ValueError, OSError):
            return None
    return None

def update_last_sync_date():
    """Update the last sync timestamp."""
    config_dir = Path.home() / ".contactcmd"
    config_dir.mkdir(exist_ok=True)
    
    sync_file = config_dir / "mac_sync_timestamp"
    now = datetime.datetime.now()
    
    with open(sync_file, "w") as f:
        f.write(str(now.timestamp()))
    
    return now